Attribute VB_Name = "cwbco"
'/********************************************************************/
'/*                                                                  */
'/* 5769-XE1                                                         */
'/* (C) Copyright IBM Corp. 1995,1998                                */
'/* All rights reserved.                                             */
'/* US Government Users Restricted Rights -                          */
'/* Use, duplication or disclosure restricted                        */
'/* by GSA ADP Schedule Contract with IBM Corp.                      */
'/*                                                                  */
'/* Licensed Materials-Property of IBM                               */
'/*                                                                  */
'/********************************************************************/
'/*                                                                  */
'/* Module:                                                          */
'/*   CWBCO.H                                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   The functions listed in this file can be used to get           */
'/*   information about environments and connections configured      */
'/*   using Client Access.                                           */
'/*                                                                  */
'/*   The APIs can be broken down into three groups:                 */
'/*                                                                  */
'/*   The following APIs can be used to create a list of configured  */
'/*   systems, either in the currently active environment or a       */
'/*   different environment.  The size (number of entries) in the    */
'/*   list, and each entry in succession, can be retrieved:          */
'/*     cwbCO_CreateSysListHandle()                                  */
'/*     cwbCO_CreateSysListHandleEnv()                               */
'/*     cwbCO_CreateSysListHandleEnvA()                              */
'/*     cwbCO_CreateSysListHandleEnvW()                              */
'/*     cwbCO_GetSysListSize()                                       */
'/*     cwbCO_GetNextSysName()                                       */
'/*     cwbCO_GetNextSysNameA()                                      */
'/*     cwbCO_GetNextSysNameW()                                      */
'/*     cwbCO_DeleteSysListHandle()                                  */
'/*                                                                  */
'/*   The following APIs can be used to get information about        */
'/*   individual systems that are configured or connected.  Unless   */
'/*   environment name is passed as a parameter, these APIs work     */
'/*   only with the currently active environment:                    */
'/*     cwbCO_GetDefaultSysName()                                    */
'/*     cwbCO_GetDefaultSysNameA()                                   */
'/*     cwbCO_GetDefaultSysNameW()                                   */
'/*     cwbCO_GetConnectedSysName()                                  */
'/*     cwbCO_GetConnectedSysNameA()                                 */
'/*     cwbCO_GetConnectedSysNameW()                                 */
'/*     cwbCO_IsSystemConfigured()                                   */
'/*     cwbCO_IsSystemConfiguredA()                                  */
'/*     cwbCO_IsSystemConfiguredW()                                  */
'/*     cwbCO_IsSystemConfiguredEnv()                                */
'/*     cwbCO_IsSystemConfiguredEnvA()                               */
'/*     cwbCO_IsSystemConfiguredEnvW()                               */
'/*     cwbCO_IsSystemConnected()                                    */
'/*     cwbCO_IsSystemConnectedA()                                   */
'/*     cwbCO_IsSystemConnectedW()                                   */
'/*     cwbCO_GetUserID()                                            */
'/*     cwbCO_GetUserIDA()                                           */
'/*     cwbCO_GetUserIDW()                                           */
'/*     cwbCO_GetActiveConversations()                               */
'/*     cwbCO_GetActiveConversationsA()                              */
'/*     cwbCO_GetActiveConversationsW()                              */
'/*     cwbCO_GetHostVersion()                                       */
'/*     cwbCO_GetHostVersionA()                                      */
'/*     cwbCO_GetHostVersionW()                                      */
'/*                                                                  */
'/*   The following APIs can be used to get names of environments    */
'/*   that have been configured:                                     */
'/*     cwbCO_GetNumberOfEnvironments()                              */
'/*     cwbCO_GetEnvironmentName()                                   */
'/*     cwbCO_GetEnvironmentNameA()                                  */
'/*     cwbCO_GetEnvironmentNameW()                                  */
'/*     cwbCO_GetActiveEnvironment()                                 */
'/*     cwbCO_GetActiveEnvironmentA()                                */
'/*     cwbCO_GetActiveEnvironmentW()                                */
'/*                                                                  */
'/*   The following APIs can be used to determine if the calling     */
'/*   application can modify/change environments and connection      */
'/*   information.                                                   */
'/*     cwbCO_CanConnectNewSystem()                                  */
'/*     cwbCO_CanSetActiveEnvironment()                              */
'/*     cwbCO_CanModifyEnvironmentList()                             */
'/*     cwbCO_CanModifySystemList()                                  */
'/*     cwbCO_CanModifySystemListEnv()                               */
'/*     cwbCO_CanModifySystemListEnvA()                              */
'/*     cwbCO_CanModifySystemListEnvW()                              */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   Some or all of the APIs can return CWBCO_INTERNAL_ERROR,       */
'/*   though this indicates a problem with Client Access and should  */
'/*   not be common.                                                 */
'/*   Link with CWBAPI.LIB import library.                           */
'/*   This module is to be used in conjunction with CWBCO.DLL.       */
'/*                                                                  */
'/*   In addition to the return codes listed for APIs additional     */
'/*   operating system specific return codes may also appear.  The   */
'/*   precise meaning of these return codes can be found in the      */
'/*   operating system manuals or relevant header files.             */
'/*                                                                  */
'/********************************************************************/

'/*------------------------------------------------------------------*/
'/* Component CO errors based on CWB_LAST (in CWB.H)                 */
'/*------------------------------------------------------------------*/
Public Const CWBCO_START = CWB_LAST + 1
Public Const CWBCO_END_OF_LIST = CWBCO_START + 1
Public Const CWBCO_DEFAULT_SYSTEM_NOT_DEFINED = CWBCO_START + 2
Public Const CWBCO_DEFAULT_SYSTEM_NOT_CONFIGURED = CWBCO_START + 3
Public Const CWBCO_SYSTEM_NOT_CONNECTED = CWBCO_START + 4
Public Const CWBCO_SYSTEM_NOT_CONFIGURED = CWBCO_START + 5
Public Const CWBCO_NO_USER_ID = CWBCO_START + 6
Public Const CWBCO_INTERNAL_ERROR = CWBCO_START + 7
Public Const CWBCO_NO_SUCH_ENVIRONMENT = CWBCO_START + 8
Public Const CWBCO_RESERVED_START = CWBCO_START + 100

'/*------------------------------------------------------------------*/
'/* Definitions to use when specifying which User ID you mean        */
'/*------------------------------------------------------------------*/
Public Const CWBCO_DEFAULT_USER_ID = 0
Public Const CWBCO_CURRENT_USER_ID = 1

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CreateSysListHandle                                      */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Creates a handle to list of configured system names in the     */
'/*   environment currently in use.                                  */
'/*                                                                  */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   cwbCO_SysListHandle *listHandle - output                       */
'/*     Pointer to a list handle that will be passed back on output. */
'/*     This handle is needed for other calls using the list.        */
'/*                                                                  */
'/*   cwbSV_ErrorHandle errorHandle - input                          */
'/*     If the API call fails, the message object associated with    */
'/*     this handle will be filled in with message text that         */
'/*     describes the error.  If this parameter is zero, no messages */
'/*     will be available.                                           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   */
'/*   CWB_INVALID_POINTER - Pointer to the list handle is NULL       */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   cwbCO_DeleteSysListHandle() must be called to free             */
'/*   resources allocated with this API.                             */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_CreateSysListHandle Lib "cwbco" _
  ( _
    ByRef listHandle As Long, _
    ByVal errorHandle As Long _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CreateSysListHandleEnv                                   */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Creates a handle to list of configured system names of the     */
'/*   specified environment.                                         */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbCO_SysListHandle *listHandle - output                       */
'/*     Pointer to a list handle that will be passed back on output. */
'/*     This handle is needed for other calls using the list.        */
'/*                                                                  */
'/*   cwbSV_ErrorHandle errorHandle - input                          */
'/*     If the API call fails, the message object associated with    */
'/*     this handle will be filled in with message text that         */
'/*     describes the error.  If this parameter is zero, no messages */
'/*     will be available.                                           */
'/*                                                                  */
'/*   LPCSTR pEnvironment - input                                    */
'/*     Pointer to a string containing the desired environment name. */
'/*     If pEnvironment is the NULL pointer, or points to the NULL   */
'/*     string ("\0"), the system list of the current active         */
'/*     environment is returned.                                     */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_INVALID_POINTER - Pointer to the list handle is NULL.      */
'/*   CWBCO_NO_SUCH_ENVIRONMENT - The specified environment does not */
'/*                               exist.                             */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   cwbCO_DeleteSysListHandle() must be called to free             */
'/*   resources allocated with this API.                             */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_CreateSysListHandleEnv Lib "cwbco" _
  ( _
    ByRef listHandle As Long, _
    ByVal errorHandle As Long, _
    ByVal pEnvironment As String _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_DeleteSysListHandle                                      */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Deletes a handle to a list of configured system names.  This   */
'/*   must be done last when finished using the system name list.    */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbCO_SysListHandle - listHandle                               */
'/*     A handle to the system name list to delete.                  */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_HANDLE - The list handle is not valid.             */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   Use this API to delete the list created with the               */
'/*   cwbCO_CreateSysListHandle or cwbCO_CreateSysListHandleEnv API. */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_DeleteSysListHandle Lib "cwbco" _
  ( _
    ByVal listHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetDefaultSysName                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the name of the default system in the active environment.  */
'/*                                                                  */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   char *defaultSystemName - output                               */
'/*     Pointer to a buffer that will contain the NULL-terminated    */
'/*     system name.                                                 */
'/*                                                                  */
'/*   unsigned long bufferSize - input                               */
'/*     Size of input buffer.                                        */
'/*                                                                  */
'/*   unsigned long *needed - output                                 */
'/*     Number of bytes needed to hold entire system name including  */
'/*     the terminating NULL.                                        */
'/*                                                                  */
'/*   cwbSV_ErrorHandle errorhandle - input                          */
'/*     If the API call fails, the message object associated with    */
'/*     this handle will be filled in with message text that         */
'/*     describes the error.  If this parameter is zero, no messages */
'/*     will be available.                                           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_POINTER - Pointer to the system name or pointer    */
'/*                         to buffer size needed is NULL.           */
'/*                         Check messages in the History Log to     */
'/*                         determine which are NULL.                */
'/*   CWB_BUFFER_OVERFLOW - Not enough room in output buffer to      */
'/*                         hold the entire system name.  Use        */
'/*                         *needed to determine the correct         */
'/*                         size.  No error message is logged to the */
'/*                         History Log since the caller is expected */
'/*                         to recover from this error and continue. */
'/*   CWBCO_DEFAULT_SYSTEM_NOT_DEFINED - The setting for the default */
'/*                                      system has not been         */
'/*                                      defined in the active       */
'/*                                      environment.                */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_GetDefaultSysName Lib "cwbco" _
  ( _
    ByVal defaultSystemName As String, _
    ByVal bufferSize As Long, _
    ByRef needed As Long, _
    ByVal errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetNextSysName                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the name of the next system from a list of systems.        */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbCO_SysListHandle handleList - input                         */
'/*     Handle to a list of systems.                                 */
'/*                                                                  */
'/*   char *systemName - output                                      */
'/*     Pointer to a buffer that will contain the system name.       */
'/*                                                                  */
'/*   unsigned long bufferSize - input                               */
'/*     Size of the buffer pointed to by systemName.                 */
'/*                                                                  */
'/*   unsigned long *needed - output                                 */
'/*     Number of bytes needed to hold entire system name.           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_HANDLE - The list handle is not valid.             */
'/*   CWB_INVALID_POINTER - Pointer to system name or pointer to     */
'/*                         buffer size needed is NULL.              */
'/*                         Check messages in the History Log to     */
'/*                         determine which are NULL.                */
'/*   CWB_BUFFER_OVERFLOW - Not enough room in output buffer to hold */
'/*                         entire system name.  Use *needed to      */
'/*                         determine the correct size.              */
'/*                         No error message is logged to the        */
'/*                         History Log since the caller is expected */
'/*                         to recover from this error and continue. */
'/*   CWBCO_END_OF_LIST   - The end of the system list has been      */
'/*                         reached. No system name was returned.    */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the system list passed in was created using the API         */
'/*   cwbCO_CreateSystemListHandle then the system returned is       */
'/*   configured in the currently active environment, unless between */
'/*   these API calls the user has removed it or switched to a       */
'/*   different environment.  If cwbCO_CreateSysListHandleEnv was    */
'/*   called to create the system list, then the system returned is  */
'/*   configured in the environment passed to that API, unless the   */
'/*   user has since removed it.                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_GetNextSysName Lib "cwbco" _
  ( _
    ByVal handleList As Long, _
    ByVal systemName As String, _
    ByVal bufferSize As Long, _
    ByRef needed As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetSysListSize                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Gets the number of system names in the list.                   */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbCO_SysListHandle listHandle - input                         */
'/*     Handle of the list of systems.                               */
'/*                                                                  */
'/*   unsigned long *listSize - output                               */
'/*     On output this will be set to the number of systems in the   */
'/*     the list.                                                    */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common reuturn values.                 */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_HANDLE - The list handle is not valid.             */
'/*   CWB_INVALID_POINTER - Pointer to the list size is NULL.        */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_GetSysListSize Lib "cwbco" _
  ( _
    ByVal listHandle As Long, _
    ByRef listSize As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetConnectedSysName                                      */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the name of the connected system corresponding to the      */
'/*   index.                                                         */
'/* Parameters:                                                      */
'/*   char *systemName - output                                      */
'/*     Pointer to a buffer that will contain the system name.       */
'/*                                                                  */
'/*   unsigned long * bufferSize - input/output                      */
'/*     input: Size of the buffer pointed to by *systemName.         */
'/*     output: Size of buffer needed.                               */
'/*                                                                  */
'/*   unsigned long index                                            */
'/*     0 corresponds to the first connected system.                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_POINTER - Pointer to system name or pointer to     */
'/*                         buffer size needed is NULL.              */
'/*                         Check messages in the History Log to     */
'/*                         determine which are NULL.                */
'/*   CWB_BUFFER_OVERFLOW - Not enough room in output buffer to hold */
'/*                         entire system name.  Use *bufferSize to  */
'/*                         determine the correct size.              */
'/*                         No error message is logged to the        */
'/*                         History Log since the caller is expected */
'/*                         to recover from this error and continue. */
'/*   CWBCO_END_OF_LIST   - The end of connected system list has     */
'/*                         been reached.  No system name was        */
'/*                         returned.                                */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   Systems can only be connected when in the currently active     */
'/*   environment, so system names returned will only be from that   */
'/*   environment.                                                   */
'/********************************************************************/
Public Declare Function cwbCO_GetConnectedSysName Lib "cwbco" _
  ( _
    ByVal systemName As String, _
    ByRef bufferSize As Long, _
    ByVal index As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_IsSystemConfigured                                       */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Check if the input system is configured in the environment     */
'/*   currently in use.                                              */
'/* Parameters:                                                      */
'/*   LPCSTR systemName - input                                      */
'/*     Pointer to a buffer that contains the system name.           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE: system is configured.                                */
'/*   CWB_FALSE: system is not configured, systemName is NULL, or    */
'/*              system name contains one or more UNICODE characters */
'/*              which cannot be converted.                          */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   None                                                           */
'/********************************************************************/
Public Declare Function cwbCO_IsSystemConfigured Lib "cwbco" _
  ( _
    ByVal systemName As String _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_IsSystemConfiguredEnv                                    */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Check if the input system is configured in the environment     */
'/*   specified.                                                     */
'/* Parameters:                                                      */
'/*   LPCSTR systemName - input                                      */
'/*     Pointer to a buffer that contains the system name.           */
'/*                                                                  */
'/*   LPCSTR pEnvironment - input                                    */
'/*     Pointer to a buffer that contains the environment name.      */
'/*     If pEnvironment is NULL, or if it points to an empty string, */
'/*     the environment currently in use is checked.                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE: system is configured.                                */
'/*   CWB_FALSE: system is not configured, environment does not      */
'/*              exist, systemName is NULL, or system name or        */
'/*              environment contains one or more UNICODE characters */
'/*              which cannot be converted.                          */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   None                                                           */
'/********************************************************************/
Public Declare Function cwbCO_IsSystemConfiguredEnv Lib "cwbco" _
  ( _
    ByVal systemName As String, _
    ByVal pEnvironment As String _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_IsSystemConnected                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Check if the input system is currently connected.              */
'/* Parameters:                                                      */
'/*   LPCSTR systemName - input                                      */
'/*     Pointer to a buffer that contains the system name.           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE: system is currently connected.                       */
'/*   CWB_FALSE: system is not connected, systemName is NULL, or     */
'/*              system name contains one or more UNICODE characters */
'/*              which cannot be converted.                          */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   Only systems configured in the currently active environment    */
'/*   can be connected to, so the system name passed in must be      */
'/*   configured in the currently active environment.                */
'/********************************************************************/
Public Declare Function cwbCO_IsSystemConnected Lib "cwbco" _
  ( _
    ByVal systemName As String _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetUserID                                                */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get signon or default user ID of the input system as it is     */
'/*   configured and possibly connected in the currently active      */
'/*   environment.                                                   */
'/* Parameters:                                                      */
'/*   LPCSTR systemName - input                                      */
'/*     Pointer to a buffer that contains the system name.           */
'/*   char *userID - output                                          */
'/*     Pointer to a buffer where the desired userID of the system   */
'/*     is returned.                                                 */
'/*   unsigned int userID_Type - input                               */
'/*     Specify whether current user ID of connected system          */
'/*     (CWBCO_CURRENT_USER_ID) or default user ID of configured     */
'/*     system (CWBCO_DEFAULT_USER_ID) is to be returned.            */
'/*   unsigned long * bufferSize - input/output                      */
'/*     Pointer to a value that indicates the size of the userID     */
'/*     buffer. If the buffer is not big enough, the value needed    */
'/*     is returned.                                                 */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_POINTER - One or more input pointers are invalid.  */
'/*                         Check messages in the History Log to     */
'/*                         determine which are invalid.             */
'/*   CWB_INVALID_PARAMETER - The value for userID_Type is invalid.  */
'/*   CWB_BUFFER_OVERFLOW - Not enough room in userID buffer to      */
'/*                         store the user ID.  Use *bufferSize to   */
'/*                         determine the correct size.              */
'/*                         No error message is logged to the        */
'/*                         History Log since the caller is expected */
'/*                         to recover from this error and continue. */
'/*   CWBCO_SYSTEM_NOT_CONNECTED - The system of the "current user   */
'/*                                ID" is not connected.             */
'/*   CWBCO_SYSTEM_NOT_CONFIGURED - The system of the "default user  */
'/*                                 ID" is not configured in the     */
'/*                                 currently active environment.    */
'/*   CWBCO_NO_USER_ID - No user ID for this system could be found,  */
'/*                      not even an empty one; this indicates a     */
'/*                      severe error, possibly registry corruption. */
'/*   CWBCO_INTERNAL_ERROR - internal error.                         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the default user ID is specified, and none was entered      */
'/*   when the connection was configured, CWB_OK will be returned    */
'/*   and the user ID sent back to the caller will be the empty      */
'/*   string, "\0".                                                  */
'/*                                                                  */
'/*   The user ID retrieved will be that of the specified system     */
'/*   from the currently active environment.                         */
'/********************************************************************/
Public Declare Function cwbCO_GetUserID Lib "cwbco" _
  ( _
    ByVal systemName As String, _
    ByVal userID As String, _
    ByVal userID_Type As Long, _
    ByRef bufferSize As Long _
  ) _
  As Long

'/********************************************************************/
'/* API:                                                             */
'/*   cwbCO_GetActiveConversations                                   */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the number of active conversations of the system.          */
'/* Parameters:                                                      */
'/*   LPCSTR systemName - input                                      */
'/*     Pointer to a buffer that contains the system name.           */
'/* Return Codes:                                                    */
'/*  The number of active conversations, if any, is returned.        */
'/*  If the systemName pointer is NULL, points to an empty string,   */
'/*  the system is not currently connected, or system name contains  */
'/*  one or more UNICODE characters which cannot be converted,       */
'/*  0 will be returned.                                             */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   Since only systems configured in the currently active          */
'/*   environment may be connected to, it is invalid to pass the     */
'/*   name of a system not configured in the currently active        */
'/*   environment; in this case, 0 is returned.                      */
'/********************************************************************/
Public Declare Function cwbCO_GetActiveConversations Lib "cwbco" _
  ( _
    ByVal systemName As String _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetHostVersion                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the version and release level of the host.                 */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   LPCSTR systemName - input                                      */
'/*     Pointer to a buffer that contains the system name.           */
'/*   unsigned int * version - output                                */
'/*     Pointer to a buffer where the version level of the system    */
'/*     is returned.                                                 */
'/*   unsigned int * release - output                                */
'/*     Pointer to a buffer where the release level of the system    */
'/*     is returned.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWBCO_SYSTEM_NOT_CONFIGURED - The system is not configured in  */
'/*                                 the currently active environment.*/
'/*   CWBCO_SYSTEM_NOT_CONNECTED - The system has never been         */
'/*                                connected to when using the       */
'/*                                currently active environment.     */
'/*   CWB_INVALID_POINTER - The pointer to the system name is NULL.  */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The host version is retrieved and saved whenever a connection  */
'/*   is made to the system; this API does not go to the host to     */
'/*   get it on each call.  The system must have been connected      */
'/*   previously, though not necessarily at the time the API is      */
'/*   called.  Host information can only be retrieved for systems    */
'/*   configured in the currently active environment.                */
'/********************************************************************/
Public Declare Function cwbCO_GetHostVersion Lib "cwbco" _
  ( _
    ByVal systemName As String, _
    ByRef version As Long, _
    ByRef release As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetNumberOfEnvironments                                  */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the number of Client Access environments that exist.  This */
'/*   includes both the active and all non-active environments.      */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   unsigned long *numberOfEnv - output                            */
'/*     On output this will be set to the number of environments.    */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_POINTER - The numberOfEnv pointer parameter        */
'/*                         is NULL.                                 */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_GetNumberOfEnvironments Lib "cwbco" _
  ( _
    ByRef numberOfEnv As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetEnvironmentName                                       */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the name of the environment corresponding to the index.    */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   char *environmentName - output                                 */
'/*     Pointer to a buffer that will contain the environment name.  */
'/*                                                                  */
'/*   unsigned long * bufferSize - input/output                      */
'/*     input: Size of the buffer pointed to by *environmentName.    */
'/*     output: Size of buffer needed, if the buffer provided was    */
'/*             too small.                                           */
'/*                                                                  */
'/*   unsigned long index - input                                    */
'/*     0 corresponds to the first environment.                      */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_POINTER - One or more pointer parameters are NULL. */
'/*                         Check messages in the History Log to     */
'/*                         determine which are invalid.             */
'/*   CWB_BUFFER_OVERFLOW - Not enough room in output buffer to hold */
'/*                         entire environment name.  Use *bufferSize*/
'/*                         to determine the correct size.           */
'/*                         No error message is logged to the        */
'/*                         History Log since the caller is expected */
'/*                         to recover from this error and continue. */
'/*   CWBCO_END_OF_LIST   - The end of the environments list has     */
'/*                         been reached.  No environment name was   */
'/*                         returned.                                */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_GetEnvironmentName Lib "cwbco" _
  ( _
    ByVal environmentName As String, _
    ByRef bufferSize As Long, _
    ByVal index As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_GetActiveEnvironment                                     */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the name of the environment currently active.              */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   char *environmentName - output                                 */
'/*     Pointer to a buffer that contains the environment name.      */
'/*                                                                  */
'/*   unsigned long * bufferSize - input/output                      */
'/*     input: Size of the buffer pointed to by *environmentName.    */
'/*     output: Size of buffer needed.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_OK - Successful Completion.                                */
'/*   CWB_INVALID_POINTER - One or more pointer parameters are NULL. */
'/*                         Check messages in the History Log to     */
'/*                         determine which are NULL.                */
'/*   CWB_BUFFER_OVERFLOW - Not enough room in output buffer to hold */
'/*                         entire environment name.  Use *bufferSize*/
'/*                         to determine the correct size.           */
'/*                         No error message is logged to the        */
'/*                         History Log since the caller is expected */
'/*                         to recover from this error and continue. */
'/*   CWBCO_NO_SUCH_ENVIRONMENT - No environments have been          */
'/*                               configured, so there is no active  */
'/*                               environment.                       */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_GetActiveEnvironment Lib "cwbco" _
  ( _
    ByVal environmentName As String, _
    ByRef bufferSize As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CanConnectNewSystem                                      */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Indicates whether or not the user can dynamically connect to   */
'/*   a system.  If not, cwbCO_CreateSystem will fail if the         */
'/*   system being connected to does not exist in the active         */
'/*   environment.                                                   */
'/*                                                                  */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   cwbCO_SysListHandle listHandle - input                         */
'/*     Handle to a list of systems.                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE - Can connect to systems not already configured       */
'/*   CWB_FALSE - Cannot connect to systems not already configured   */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/

'NOTE:  The comment for this API incorrectly lists a parameter that
'       is not part of the actual API call.
Public Declare Function cwbCO_CanConnectNewSystem Lib "cwbco" _
  ( _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CanSetActiveEnvironment                                  */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Indicates whether or not the user can set an environment to be */
'/*   the active environment.                                        */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   None                                                           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE - Can set the active environment                      */
'/*   CWB_FALSE - Cannot set the active environment                  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_CanSetActiveEnvironment Lib "cwbco" _
  ( _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CanModifyEnvironmentList                                 */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Indicates whether or not the user can create/remove/rename     */
'/*   environments.                                                  */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   None                                                           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE - Can create/remove/rename/delete environments        */
'/*   CWB_FALSE - Cannot create/remove/rename/delete environments    */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This API indicates whether environments can be manipulated.    */
'/*   To see if systems within an environment may be manipulated,    */
'/*   use the cwbCO_CanModifySystemList and                          */
'/*   cwbCO_CanModifySystemListEnv APIs.                             */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_CanModifyEnvironmentList Lib "cwbco" _
  ( _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CanModifySystemList                                      */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Indicates whether or not the user can add/remove/delete        */
'/*   systems within the active environment.  Note that systems      */
'/*  "suggested" by the administrator via policies cannot be removed.*/
'/*                                                                  */
'/* Parameters:                                                      */
'/*   None                                                           */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE - Can modify system list                              */
'/*   CWB_FALSE - Cannot modify system list                          */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This API indicates whether systems within an environment can   */
'/*   be manipulated.  To see if environments can be manipulated     */
'/*   see the cwbCO_CanModifyEnvironmentList API.                    */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_CanModifySystemList Lib "cwbco" _
  ( _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbCO_CanModifySystemListEnv                                   */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Indicates whether or not the user can add/remove/delete        */
'/*   systems within an input environment.  Note that systems        */
'/*  "suggested" by the administrator via policies cannot be removed.*/
'/*                                                                  */
'/* Parameters:                                                      */
'/*   LPCSTR pEnvironment                                            */
'/*     Pointer to a string containing the desired environment name. */
'/*     If pEnvironment is the NULL pointer, or points to the NULL   */
'/*     string ("\0"), the active environment is assumed.            */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*  The following list shows common return values.                  */
'/*   CWB_TRUE - Can modify system list                              */
'/*   CWB_FALSE - Cannot modify system list, error occurred.         */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This API indicates whether systems within an environment can   */
'/*   be manipulated.  To see if environments can be manipulated     */
'/*   see the cwbCO_CanModifyEnvironmentList API.                    */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbCO_CanModifySystemListEnv Lib "cwbco" _
  ( _
    ByVal pEnvironment As String _
  ) _
  As Long


