Attribute VB_Name = "cwbsv"
'/********************************************************************/
'/*                                                                  */
'/* 5769-XE1                                                         */
'/* (C) Copyright IBM Corp. 1995,1998                                */
'/* All rights reserved.                                             */
'/* US Government Users Restricted Rights -                          */
'/* Use, duplication or disclosure restricted                        */
'/* by GSA ADP Schedule Contract with IBM Corp.                      */
'/*                                                                  */
'/* Licensed Materials-Property of IBM                               */
'/*                                                                  */
'/********************************************************************/
'/*                                                                  */
'/* Module:                                                          */
'/*   CWBSV.H                                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   It contains the declarations for the following API's:          */
'/*                                                                  */
'/*     Writing message text to the history log                      */
'/*        cwbSV_CreateMessageTextHandle()                           */
'/*        cwbSV_DeleteMessageTextHandle()                           */
'/*        cwbSV_SetMessageProduct()                                 */
'/*        cwbSV_SetMessageComponent()                               */
'/*        cwbSV_SetMessageClass()                                   */
'/*        cwbSV_LogMessageText()                                    */
'/*                                                                  */
'/*     Writing trace data to a detail trace file                    */
'/*        cwbSV_CreateTraceDataHandle()                             */
'/*        cwbSV_DeleteTraceDataHandle()                             */
'/*        cwbSV_SetTraceProduct()                                   */
'/*        cwbSV_SetTraceComponent()                                 */
'/*        cwbSV_LogTraceData()                                      */
'/*                                                                  */
'/*     Writing trace points to an entry/exit trace file             */
'/*        cwbSV_CreateTraceAPIHandle()                              */
'/*        cwbSV_DeleteTraceAPIHandle()                              */
'/*        cwbSV_SetAPIProduct()                                     */
'/*        cwbSV_SetAPIComponent()                                   */
'/*        cwbSV_LogAPIEntry()                                       */
'/*        cwbSV_LogAPIExit()                                        */
'/*        cwbSV_CreateTraceSPIHandle()                              */
'/*        cwbSV_DeleteTraceSPIHandle()                              */
'/*        cwbSV_SetSPIProduct()                                     */
'/*        cwbSV_SetSPIComponent()                                   */
'/*        cwbSV_LogSPIEntry()                                       */
'/*        cwbSV_LogSPIExit()                                        */
'/*                                                                  */
'/*     Reading service files                                        */
'/*        cwbSV_GetServiceFileName()                                */
'/*        cwbSV_OpenServiceFile()                                   */
'/*        cwbSV_CloseServiceFile()                                  */
'/*        cwbSV_ClearServiceFile()                                  */
'/*        cwbSV_GetRecordCount()                                    */
'/*        cwbSV_GetMaxRecordSize()                                  */
'/*                                                                  */
'/*     Reading service file records                                 */
'/*        cwbSV_CreateServiceRecHandle()                            */
'/*        cwbSV_DeleteServiceRecHandle()                            */
'/*        cwbSV_ReadOldestRecord()                                  */
'/*        cwbSV_ReadNewestRecord()                                  */
'/*        cwbSV_ReadPrevRecord()                                    */
'/*        cwbSV_ReadNextRecord()                                    */
'/*                                                                  */
'/*     Reading service record header information                    */
'/*        cwbSV_GetProduct()                                        */
'/*        cwbSV_GetComponent()                                      */
'/*        cwbSV_GetServiceType()                                    */
'/*        cwbSV_GetDateStamp()                                      */
'/*        cwbSV_GetTimeStamp()                                      */
'/*                                                                  */
'/*     Reading history log service records                          */
'/*        cwbSV_GetMessageText()                                    */
'/*                                                                  */
'/*     Reading detail trace file service records                    */
'/*        cwbSV_GetTraceData()                                      */
'/*                                                                  */
'/*     Reading entry/exit trace file service records                */
'/*        cwbSV_GetTraceAPIID()                                     */
'/*        cwbSV_GetTraceAPIType()                                   */
'/*        cwbSV_GetTraceAPIData()                                   */
'/*        cwbSV_GetTraceSPIID()                                     */
'/*        cwbSV_GetTraceSPIType()                                   */
'/*        cwbSV_GetTraceSPIData()                                   */
'/*                                                                  */
'/*     Retrieving message attributes associated with error handles  */
'/*        cwbSV_CreateErrHandle()                                   */
'/*        cwbSV_DeleteErrHandle()                                   */
'/*        cwbSV_GetErrCount()                                       */
'/*        cwbSV_GetErrText()                                        */
'/*        cwbSV_GetErrTextIndexed()                                 */
'/*        cwbSV_GetErrClass()                                       */
'/*        cwbSV_GetErrClassIndexed()                                */
'/*        cwbSV_GetErrFileName()                                    */
'/*        cwbSV_GetErrFileNameIndexed()                             */
'/*        cwbSV_GetErrLibName()                                     */
'/*        cwbSV_GetErrLibNameIndexed()                              */
'/*        cwbSV_GetErrSubstText()                                   */
'/*        cwbSV_GetErrSubstTextIndexed()                            */
'/*                                                                  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   Link with the CWBAPI.LIB import library.                       */
'/*   This module is to be used in conjunction with CWBSV.DLL.       */
'/*                                                                  */
'/*   Distinction between API & SPI trace points:                    */
'/*   ------------------------------------------                     */
'/*     Definitions:                                                 */
'/*       - API (Application Programming Interface)                  */
'/*       - SPI (System Programming Interface)                       */
'/*                                                                  */
'/*   The recommended convention is that API entry/exit trace        */
'/*   points should be put in routines that you externalize (export) */
'/*   to your users. SPI entry/exit trace points should be used in   */
'/*   key internal (non-exported) routines that you want to trace.   */
'/*                                                                  */
'/********************************************************************/

'/*------------------------------------------------------------------*/
'/* TYPEDEFS:                                                        */
'/*------------------------------------------------------------------*/

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_ServiceFileType                               */
'/*------------------------------------------------------------------*/
Global Const CWBSV_HISTORY_LOG = 0
Global Const CWBSV_PROBLEM_LOG = 1
Global Const CWBSV_DETAIL_TRACE_FILE = 2
Global Const CWBSV_ENTRY_EXIT_TRACE_FILE = 3

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_ServiceRecType                                */
'/*------------------------------------------------------------------*/
Global Const CWBSV_MESSAGE_REC = 0
Global Const CWBSV_PROBLEM_REC = 1
Global Const CWBSV_DATA_TRACE_REC = 2
Global Const CWBSV_API_TRACE_REC = 3
Global Const CWBSV_SPI_TRACE_REC = 4

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_EventType                                     */
'/*------------------------------------------------------------------*/
Global Const CWBSV_ENTRY_POINT = 0
Global Const CWBSV_EXIT_POINT = 1

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_ProblemType                                   */
'/*------------------------------------------------------------------*/
Global Const CWBSV_APP_DETECTED = 0
Global Const CWBSV_USER_DETECTED = 1

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_CreatedBy                                     */
'/*------------------------------------------------------------------*/
Global Const CWBSV_OWNER_CLIENTACCESS = "P"

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_ProblemSeverity                               */
'/*------------------------------------------------------------------*/
Global Const CWBSV_SEV_HIGH = 1
Global Const CWBSV_SEV_MEDIUM = 2
Global Const CWBSV_SEV_LOW = 3
Global Const CWBSV_SEV_NONE = 4

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_ProblemStatus                                 */
'/*------------------------------------------------------------------*/
Global Const CWBSV_STATUS_READY = "R"
Global Const CWBSV_STATUS_SENT = "S"

'/*------------------------------------------------------------------*/
'/* DEFINES: for cwbSV_MessageClass                                  */
'/*  - Use first 3 on cwbSV_SetMessageClass()                        */
'/*  - Also returned from cwbSV_GetErrClass()                        */
'/*                       cwbSV_GetErrClassIndexed()                 */
'/*------------------------------------------------------------------*/
Global Const CWBSV_CLASS_INFORMATIONAL = 0
Global Const CWBSV_CLASS_WARNING = 1
Global Const CWBSV_CLASS_ERROR = 2

Global Const CWBSV_CLASS_ERROR_RETRY = 1     '// same as CWBSV_CLASS_WARNING
Global Const CWBSV_CLASS_ERROR_ABORT = 2     '// same as CWBSV_CLASS_ERROR

'/*------------------------------------------------------------------*/
'/* Possibly returned by cwbSV_GetErrClass() and                     */
'/*                      cwbSV_GetErrClassIndexed()                  */
'/* Do not use on cwbSV_SetMessageClass()                            */
'/*------------------------------------------------------------------*/
Global Const CWBSV_CLASS_HOST_WARNING = 10
Global Const CWBSV_CLASS_HOST_ERORR = 20
Global Const CWBSV_CLASS_HOST_SEV_ERROR = 30
Global Const CWBSV_CLASS_HOST_SEV_ERROR_ABEND = 40
Global Const CWBSV_CLASS_HOST_JOB_ABEND = 50
Global Const CWBSV_CLASS_HOST_SYS_STATUS = 60
Global Const CWBSV_CLASS_HOST_DEVICE_INTEGRITY = 70
Global Const CWBSV_CLASS_HOST_SYS_ALERT = 80
Global Const CWBSV_CLASS_HOST_SYS_INTEGRITY = 90
Global Const CWBSV_CLASS_HOST_ACTION_REQUIRED = 99

'/*------------------------------------------------------------------*/
'/* DEFINES: for maximum string lengths                              */
'/*------------------------------------------------------------------*/
Global Const CWBSV_MAX_FILE_PATH = 260             '/* Service file path                 */

Global Const CWBSV_MAX_PRODUCT_ID = 32 + 1         '/* Service Rec: Product ID           */
Global Const CWBSV_MAX_COMP_ID = 32 + 1            '/* Service Rec: Component ID         */
Global Const CWBSV_MAX_DATE_VALUE = 24 + 1         '/* Service Rec: Date (locale format) */
Global Const CWBSV_MAX_TIME_VALUE = 24 + 1         '/* Service Rec: Time (locale format) */

Global Const CWBSV_MAX_PROBLEM_ID = 10 + 1         '/* Problem Rec: Problem ID           */
Global Const CWBSV_MAX_PROBLEM_TEXT = 7 + 1        '/* Problem Rec: Problem text         */
Global Const CWBSV_MAX_FAIL_PRODUCT_ID = 64 + 1    '/* Problem Rec: Failing product ID   */
Global Const CWBSV_MAX_FAIL_VERSION = 64 + 1       '/* Problem Rec: Failing version      */
Global Const CWBSV_MAX_CURRENT_FIX = 8 + 1         '/* Problem Rec: Current fix level    */
Global Const CWBSV_MAX_PREVIOUS_FIX = 8 + 1        '/* Problem Rec: Previous fix level   */
Global Const CWBSV_MAX_FAIL_PATH = 1024 + 1        '/* Problem Rec: Failing path         */
Global Const CWBSV_MAX_FAIL_MODULE = 64 + 1        '/* Problem Rec: Failing module name  */
Global Const CWBSV_MAX_FAIL_METHOD = 32 + 1        '/* Problem Rec: Failing method name  */
Global Const CWBSV_MAX_SYMPTOM_STRING = 256 + 1    '/* Problem Rec: Symptom string       */
Global Const CWBSV_MAX_ORIGIN_SYS_ID = 256 + 1     '/* Problem Rec: Origin system ID     */
Global Const CWBSV_MAX_ORIGIN_IP_ADDR = 15 + 1     '/* Problem Rec: Origin IP address    */

Global Const CWBSV_MAX_MSGFILE_NAME = 10 + 1       '/* Error handle: Msg file name       */
Global Const CWBSV_MAX_MSGFILE_LIBR = 10 + 1       '/* Error handle: Msg file library    */

'/*------------------------------------------------------------------*/
'/* DEFINES: CWBSV.H specific return codes                           */
'/*------------------------------------------------------------------*/
Global Const CWBSV_START = CWB_LAST + 1           '/* CWB_LAST defined in CWB.H */

Global Const CWBSV_INVALID_FILE_TYPE = CWBSV_START
Global Const CWBSV_INVALID_RECORD_TYPE = CWBSV_START + 1
Global Const CWBSV_INVALID_EVENT_TYPE = CWBSV_START + 2
Global Const CWBSV_NO_ERROR_MESSAGES = CWBSV_START + 3
Global Const CWBSV_ATTRIBUTE_NOT_SET = CWBSV_START + 4
Global Const CWBSV_INVALID_MSG_CLASS = CWBSV_START + 5


'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_ClearServiceFile                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Clears the service file identified by the handle provided.     */
'/*   This means all service records are deleted and the service     */
'/*   file will be empty.                                            */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_FILE_IO_ERROR - File could not be cleared.                 */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_ClearServiceFile Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByVal errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CloseServiceFile                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Closes the service file identified by the handle provided.     */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() function.                          */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_FILE_IO_ERROR - File could not be closed.                  */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CloseServiceFile Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByVal errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CreateErrHandle                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function creates an error message object and returns a    */
'/*   handle to it. This error handle can be passed to Client        */
'/*   Access/400 API's that support it. If an error occurs on one    */
'/*   of these API's, the error handle can be used to retrieve the   */
'/*   error messages associated with the API error.                  */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle * errorHandle -input/output                    */
'/*       Pointer to a cwbSV_ErrHandle where the handle will be      */
'/*       returned.                                                  */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed as handle address            */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CreateErrHandle Lib "cwbsv" _
  ( _
    ByRef errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CreateMessageTextHandle                                  */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function creates a message text object and returns a      */
'/*   handle to it. This message handle can be used in your program  */
'/*   to write message text to the currently active history log.     */
'/*   The message text is supplied in a buffer passed on the         */
'/*   cwbSV_LogMessageText() API.                                    */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this message entry.       */
'/*       Parameter is optional, if null, no productID is set.       */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this message entry.     */
'/*       Parameter is optional, if null, no componentID is set.     */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   cwbSV_MessageTextHandle * messageTextHandle - input/output     */
'/*       Pointer to a cwbSV_MessageTextHandle where the handle      */
'/*       will be returned. This handle should be used in            */
'/*       subsequent calls to the message text functions.            */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   It is recommended that you set a unique product ID and         */
'/*   component ID in the message handle before using it to log      */
'/*   message text. These ID's will distinguish your messages from   */
'/*   other messages in the history log.                             */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CreateMessageTextHandle Lib "cwbsv" _
  ( _
    ByVal productID As String, _
    ByVal componentID As String, _
    ByRef messageTextHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CreateServiceRecHandle                                   */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function creates a service record object and returns a    */
'/*   handle to it. This handle is used to access information        */
'/*   contained in service file records.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle * serviceRecHandle - input/output       */
'/*       Pointer to a cwbSV_ServiceRecordHandle where the handle    */
'/*       will be returned. This handle should be used in            */
'/*       subsequent calls to the service record functions.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed as handle address.           */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This handle can be used in your program to read records from   */
'/*   an open service file and extract information from the record.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CreateServiceRecHandle Lib "cwbsv" _
  ( _
    ByRef serviceRecHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CreateTraceAPIHandle                                     */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function creates a trace API object and returns a handle  */
'/*   to it. This trace API handle can be used in your program to    */
'/*   log entry into and exit from an API entry point.               */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this message entry.       */
'/*       Parameter is optional, if null, no productID is set.       */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this message entry.     */
'/*       Parameter is optional, if null, no componentID is set.     */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   cwbSV_TraceAPIHandle * traceAPIHandle - input/output           */
'/*       Pointer to a cwbSV_TraceAPIHandle where the handle         */
'/*       will be returned. This handle should be used in            */
'/*       subsequent calls to the trace API functions.               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   It is recommended that you set a unique product ID and         */
'/*   component ID in the trace data handle before using it to log   */
'/*   trace entries. These ID's will distinguish your trace entries  */
'/*   from other entries in the trace file.                          */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CreateTraceAPIHandle Lib "cwbsv" _
  ( _
    ByVal productID As String, _
    ByVal componentID As String, _
    ByRef traceAPIHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CreateTraceDataHandle                                    */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function creates a trace data object and returns a        */
'/*   handle to it. This trace handle can be used in your program to */
'/*   log trace information to trace files. The trace information is */
'/*   supplied in a buffer passed on the cwbSV_LogTraceData() API.   */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this message entry.       */
'/*       Parameter is optional, if null, no productID is set.       */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this message entry.     */
'/*       Parameter is optional, if null, no componentID is set.     */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   cwbSV_TraceDataHandle * traceDataHandle - input/output         */
'/*       Pointer to a cwbSV_TraceDataHandle where the handle        */
'/*       will be returned. This handle should be used in            */
'/*       subsequent calls to the trace data functions.              */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   It is recommended that you set a unique product ID and         */
'/*   component ID in the trace data handle before using it to log   */
'/*   trace entries. These ID's will distinguish your trace entries  */
'/*   from other entries in the trace file.                          */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CreateTraceDataHandle Lib "cwbsv" _
  ( _
    ByVal productID As String, _
    ByVal componentID As String, _
    ByRef traceDataHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_CreateTraceSPIHandle                                     */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function creates a trace SPI object and returns a handle  */
'/*   to it. This trace SPI handle can be used in your program to    */
'/*   log entry into and exit from an SPI entry point.               */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this message entry.       */
'/*       Parameter is optional, if null, no productID is set.       */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this message entry.     */
'/*       Parameter is optional, if null, no componentID is set.     */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/*   cwbSV_TraceSPIHandle * traceSPIHandle - input/output           */
'/*       Pointer to a cwbSV_TraceSPIHandle where the handle         */
'/*       will be returned. This handle should be used in            */
'/*       subsequent calls to the trace SPI functions.               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   It is recommended that you set a unique product ID and         */
'/*   component ID in the trace data handle before using it to log   */
'/*   trace entries. These ID's will distinguish your trace entries  */
'/*   from other entries in the trace file.                          */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_CreateTraceSPIHandle Lib "cwbsv" _
  ( _
    ByVal productID As String, _
    ByVal componentID As String, _
    ByRef traceSPIHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_DeleteErrHandle                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function deletes the error message object that is         */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should be made when the handle is no longer needed.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_DeleteErrHandle Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_DeleteMessageTextHandle                                  */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function deletes the message text object that is          */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_MessageTextHandle messageTextHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateMessageTextHandle() API.                       */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle passed in on request.      */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should be made when the handle is no longer needed.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_DeleteMessageTextHandle Lib "cwbsv" _
  ( _
    ByVal messageTextHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_DeleteServiceRecHandle                                   */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function deletes the service record object that is        */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should be made when the handle is no longer needed.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_DeleteServiceRecHandle Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_DeleteTraceAPIHandle                                     */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function deletes the trace API object that is             */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceAPIHandle traceAPIHandle - input                    */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateTraceAPIHandle() API.                          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should be made when the handle is no longer needed.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_DeleteTraceAPIHandle Lib "cwbsv" _
  ( _
    ByVal traceAPIHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_DeleteTraceDataHandle                                    */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function deletes the trace data object that is            */
'/*   identified by the trace handle provided.                       */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceDataHandle traceDataHandle - input                  */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateTraceDataHandle() API.                         */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should be made when the handle is no longer needed.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_DeleteTraceDataHandle Lib "cwbsv" _
  ( _
    ByVal traceDataHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_DeleteTraceSPIHandle                                     */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function deletes the trace SPI object that is             */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceSPIHandle traceSPIHandle - input                    */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateTraceSPIHandle() API.                          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should be made when the handle is no longer needed.  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_DeleteTraceSPIHandle Lib "cwbsv" _
  ( _
    ByVal traceSPIHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetComponent                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the component ID for the service record handle         */
'/*   provided.                                                      */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * componentID - input/output                              */
'/*       Pointer to a buffer that will receive the component ID     */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*   unsigned long componentIDLength - input                        */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_COMP_ID.           */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parm               */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The service record handle needs to be filled in by a call to   */
'/*   a "read" function before calling this routine, otherwise a     */
'/*   NULL string will be returned.                                  */
'/*                                                                  */
'/*   This function is valid for all service record types.           */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetComponent Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetCreatedBy                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetCurrentFix                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetDateStamp                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the datestamp (in localized format) for the service    */
'/*   record handle provided.                                        */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * dateStamp - input/output                                */
'/*       Pointer to a buffer that will receive the datestamp        */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*   unsigned long dateStampLength - input                          */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_DATE_VALUE.        */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The service record handle needs to be filled in by a call to   */
'/*   a "read" function before calling this routine, otherwise a     */
'/*   NULL string will be returned.                                  */
'/*                                                                  */
'/*   This function is valid for all service record types.           */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetDateStamp Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef dateStamp As Byte, _
    ByVal dateStampLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrClass                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message class for the top-level (i.e. most recent) */
'/*   message added to the error handle provided. This attribute     */
'/*   indicates the message severity level.                          */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long * errorClass - output                            */
'/*       Pointer to a variable that will receive the message        */
'/*       severity stored in the message identified by the handle.   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   See global const's in cwbsv.h for errorClass return values.         */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrClass Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByRef errorClass As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrClassIndexed                                       */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message class for the message identified by the    */
'/*   index provided. This attribute indicates the message severity  */
'/*   level.                                                         */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long index - input                                    */
'/*       Index value indicating which error class to return if      */
'/*       multiple errors are associated with the error handle.      */
'/*       The valid index range is from 1 to the number of messages  */
'/*       contained in the error handle. The number of messages      */
'/*       can be obtained by calling the cwbSV_GetErrCount() API.    */
'/*                                                                  */
'/*   unsigned long * errorClass - output                            */
'/*       Pointer to a variable that will receive the message        */
'/*       severity stored in the message identified by the index.    */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   An index value of 1 works with the lowest-level (i.e. oldest)  */
'/*   message in the error handle. An index value equal to the count */
'/*   returned by the cwbSV_GetErrCount() API works with the         */
'/*   top-level (i.e. most recent) message in the error handle.      */
'/*                                                                  */
'/*   Index values less than 1 act as if 1 was passed in. Index      */
'/*   values greater than the number of messages contained in the    */
'/*   error handle act as if the returned count value from the       */
'/*   cwbSV_GetErrCount() API was passed in.                         */
'/*                                                                  */
'/*   See global const's in cwbsv.h for errorClass return values.    */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrClassIndexed Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal index As Long, _
    ByRef errorClass As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrCount                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the number of messages associated with the error       */
'/*   handle provided.                                               */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long * count - input/output                           */
'/*       Pointer to variable that receives the number of messages   */
'/*       associated with this error handle. If zero is returned,    */
'/*       no errors are associated with the error handle.            */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrCount Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByRef count As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrFileName                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message file name for the top-level                */
'/*   (i.e. most recent) message added to the error handle provided. */
'/*   This message attribute only pertains to messages returned from */
'/*   the AS/400. The file name is the name of the AS/400 message    */
'/*   file containing the message.                                   */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   char * fileName - input/output                                 */
'/*       Pointer to a buffer that will receive the message file     */
'/*       name stored in the error identified by the handle.         */
'/*       The value returned is an ASCIIZ string.                    */
'/*                                                                  */
'/*   unsigned long fileNameLength - input                           */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_MSGFILE_NAME.      */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*   CWBSV_ATTRIBUTE_NOT_SET - Attribute not set in current message.*/
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   AS/400 messages may be added to the error handle when using    */
'/*   the cwbRC_CallPgm() and cwbRC_RunCmd() API's. In these cases,  */
'/*   you can use this API to retrieve the message file name for     */
'/*   the AS/400 messages contained in the error handle.             */
'/*                                                                  */
'/*   If there is no message file name attribute for the message,    */
'/*   return code CWBSV_ATTRIBUTE_NOT_SET will be returned.          */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrFileName Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal fileName As String, _
    ByVal fileNameLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrFileNameIndexed                                    */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message file name for the message identified by    */
'/*   the index provided. This message attribute only pertains to    */
'/*   messages returned from the AS/400. The file name is the name   */
'/*   of the AS/400 message file containing the message.             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long index - input                                    */
'/*       Index value indicating which message file name to return   */
'/*       if multiple errors are associated with the error handle.   */
'/*       The valid index range is from 1 to the number of messages  */
'/*       contained in the error handle. The number of messages      */
'/*       can be obtained by calling the cwbSV_GetErrCount() API.    */
'/*                                                                  */
'/*   char * fileName - input/output                                 */
'/*       Pointer to a buffer that will receive the message file     */
'/*       name stored in the error identified by the index.          */
'/*       The value returned is an ASCIIZ string.                    */
'/*                                                                  */
'/*   unsigned long fileNameLength - input                           */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_MSGFILE_NAME.      */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*   CWBSV_ATTRIBUTE_NOT_SET - Attribute not set in current message.*/
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   AS/400 messages may be added to the error handle when using    */
'/*   the cwbRC_CallPgm() and cwbRC_RunCmd() API's. In these cases,  */
'/*   you can use this API to retrieve the message file name for     */
'/*   the AS/400 messages contained in the error handle.             */
'/*                                                                  */
'/*   If there is no message file name attribute for the message,    */
'/*   return code CWBSV_ATTRIBUTE_NOT_SET will be returned.          */
'/*                                                                  */
'/*   An index value of 1 works with the lowest-level (i.e. oldest)  */
'/*   message in the error handle. An index value equal to the count */
'/*   returned by the cwbSV_GetErrCount() API works with the         */
'/*   top-level (i.e. most recent) message in the error handle.      */
'/*                                                                  */
'/*   Index values less than 1 act as if 1 was passed in. Index      */
'/*   values greater than the number of messages contained in the    */
'/*   error handle act as if the returned count value from the       */
'/*   cwbSV_GetErrCount() API was passed in.                         */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrFileNameIndexed Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal index As Long, _
    ByVal fileName As String, _
    ByVal fileNameLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrLibName                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message file library name for the top-level        */
'/*   (i.e. most recent) message added to the error handle provided. */
'/*   This message attribute only pertains to messages returned      */
'/*   from the AS/400. The library name is the  name of the AS/400   */
'/*   library containing the message file for the message.           */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   char * libraryName - input/output                              */
'/*       Pointer to a buffer that will receive the message file     */
'/*       library name stored in the error identified by the handle. */
'/*       The value returned is an ASCIIZ string.                    */
'/*                                                                  */
'/*   unsigned long libraryNameLength - input                        */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_MSGFILE_LIBR.      */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*   CWBSV_ATTRIBUTE_NOT_SET - Attribute not set in current message.*/
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   AS/400 messages may be added to the error handle when using    */
'/*   the cwbRC_CallPgm() and cwbRC_RunCmd() API's. In these cases,  */
'/*   you can use this API to retrieve the message file library      */
'/*   name for the AS/400 messages contained in the error handle.    */
'/*                                                                  */
'/*   If there is no message file library name attribute for the     */
'/*   message, return code CWBSV_ATTRIBUTE_NOT_SET will be returned. */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrLibName Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal libraryName As String, _
    ByVal libraryNameLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrLibNameIndexed                                     */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message file library name for the message          */
'/*   identified by the index provided. This message attribute only  */
'/*   pertains to messages returned from the AS/400. The library     */
'/*   name is the name of the AS/400 library containing the message  */
'/*   file for the message.                                          */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long index - input                                    */
'/*       Index value indicating which message file library name to  */
'/*       return if multiple errors are associated with the error    */
'/*       handle. The valid index range is from 1 to the number of   */
'/*       messages contained in the error handle. The number of      */
'/*       messages can be obtained by calling the                    */
'/*       cwbSV_GetErrCount() API.                                   */
'/*                                                                  */
'/*   char * libraryName - input/output                              */
'/*       Pointer to a buffer that will receive the message file     */
'/*       library name stored in the error identified by the index.  */
'/*       The value returned is an ASCIIZ string.                    */
'/*                                                                  */
'/*   unsigned long libraryNameLength - input                        */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_MSGFILE_LIBR.      */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*   CWBSV_ATTRIBUTE_NOT_SET - Attribute not set in current message.*/
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   AS/400 messages may be added to the error handle when using    */
'/*   the cwbRC_CallPgm() and cwbRC_RunCmd() API's. In these cases,  */
'/*   you can use this API to retrieve the message file library      */
'/*   name for the AS/400 messages contained in the error handle.    */
'/*                                                                  */
'/*   If there is no message file library name attribute for the     */
'/*   message, return code CWBSV_ATTRIBUTE_NOT_SET will be returned. */
'/*                                                                  */
'/*   An index value of 1 works with the lowest-level (i.e. oldest)  */
'/*   message in the error handle. An index value equal to the count */
'/*   returned by the cwbSV_GetErrCount() API works with the         */
'/*   top-level (i.e. most recent) message in the error handle.      */
'/*                                                                  */
'/*   Index values less than 1 act as if 1 was passed in. Index      */
'/*   values greater than the number of messages contained in the    */
'/*   error handle act as if the returned count value from the       */
'/*   cwbSV_GetErrCount() API was passed in.                         */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrLibNameIndexed Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal index As Long, _
    ByVal libraryName As String, _
    ByVal libraryNameLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrSubstText                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message substitution text for the top-level        */
'/*   (i.e. most recent) message identified by the error handle      */
'/*   provided. This message attribute only pertains to messages     */
'/*   returned from the AS/400. The substitution text is the data    */
'/*   inserted into the substitution variable fields defined for     */
'/*   the message.                                                   */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   char * substitutionText - input/output                         */
'/*       Pointer to a buffer that will receive the substitution     */
'/*       text for the message identified by the handle.             */
'/*                                                                  */
'/*       Note: The data returned is binary, hence it is NOT         */
'/*             returned as an ASCIIZ string. Any character strings  */
'/*             contained in the substitution text are returned      */
'/*             as EBCDIC values.                                    */
'/*                                                                  */
'/*   unsigned long substitutionTextLength - input                   */
'/*       Length of the receive buffer passed in. If the buffer      */
'/*       is too small, the value will be truncated and              */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output data if the      */
'/*       receive buffer is too small. It will also be set to the    */
'/*       actual number of bytes of output data returned upon        */
'/*       successful completion.                                     */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*   CWBSV_ATTRIBUTE_NOT_SET - Attribute not set in current message.*/
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   AS/400 messages may be added to the error handle when using    */
'/*   the cwbRC_CallPgm() and cwbRC_RunCmd() API's. In these cases,  */
'/*   you can use this API to retrieve the substitution text for     */
'/*   the AS/400 messages contained in the error handle.             */
'/*                                                                  */
'/*   If there is no substitution text for the message, return code  */
'/*   CWBSV_ATTRIBUTE_NOT_SET will be returned.                      */
'/*                                                                  */
'/*   Use the returnLength parameter to determine the actual number  */
'/*   of bytes returned in the substitution text when the return     */
'/*   code is CWB_OK.                                                */
'/*                                                                  */
'/*   The substitution text returned on this API could be used on    */
'/*   a subsequent host retrieve message API call (QSYS/QMHRTVM)     */
'/*   to retrieve the format of the substitution text or to return   */
'/*   secondary help text with the substitution text added in.       */
'/*   Host API's are called using the cwbRC_CallPgm() API.           */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrSubstText Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal substitutionText As String, _
    ByVal substitutionTextLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrSubstTextIndexed                                   */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message substitution text for the message          */
'/*   identified by the index provided. This message attribute only  */
'/*   pertains to messages returned from the AS/400. The             */
'/*   substitution text is the data inserted into the substitution   */
'/*   variable fields defined for the message.                       */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long index - input                                    */
'/*       Index value indicating which substitution text to return   */
'/*       if multiple errors are associated with the error handle.   */
'/*       The valid index range is from 1 to the number of messages  */
'/*       contained in the error handle. The number of messages can  */
'/*       be obtained by calling the cwbSV_GetErrCount() API.        */
'/*                                                                  */
'/*   char * substitutionText - input/output                         */
'/*       Pointer to a buffer that will receive the substitution     */
'/*       text stored in the error identified by the index.          */
'/*                                                                  */
'/*       Note: The data returned is binary, hence it is NOT         */
'/*             returned as an ASCIIZ string. Any character strings  */
'/*             contained in the substitution text are returned      */
'/*             as EBCDIC values.                                    */
'/*                                                                  */
'/*   unsigned long substitutionTextLength - input                   */
'/*       Length of the receive buffer passed in. If the buffer      */
'/*       is too small, the value will be truncated and              */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output data if the      */
'/*       receive buffer is too small. It will also be set to the    */
'/*       actual number of bytes of output data returned upon        */
'/*       successful completion.                                     */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*   CWBSV_ATTRIBUTE_NOT_SET - Attribute not set in current message.*/
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   AS/400 messages may be added to the error handle when using    */
'/*   the cwbRC_CallPgm() and cwbRC_RunCmd() API's. In these cases,  */
'/*   you can use this API to retrieve the substitution text for     */
'/*   the AS/400 messages contained in the error handle.             */
'/*                                                                  */
'/*   If there is no substitution text for the message, return code  */
'/*   CWBSV_ATTRIBUTE_NOT_SET will be returned.                      */
'/*                                                                  */
'/*   An index value of 1 works with the lowest-level (i.e. oldest)  */
'/*   message in the error handle. An index value equal to the count */
'/*   returned by the cwbSV_GetErrCount() API works with the         */
'/*   top-level (i.e. most recent) message in the error handle.      */
'/*                                                                  */
'/*   Index values less than 1 act as if 1 was passed in. Index      */
'/*   values greater than the number of messages contained in the    */
'/*   error handle act as if the returned count value from the       */
'/*   cwbSV_GetErrCount() API was passed in.                         */
'/*                                                                  */
'/*   Use the returnLength parameter to determine the actual number  */
'/*   of bytes returned in the substitution text when the return     */
'/*   code is CWB_OK.                                                */
'/*                                                                  */
'/*   The substitution text returned on this API could be used on    */
'/*   a subsequent host retrieve message API call (QSYS/QMHRTVM)     */
'/*   to retrieve the format of the substitution text or to return   */
'/*   secondary help text with the substitution text added in.       */
'/*   Host API's are called using the cwbRC_CallPgm() API.           */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrSubstTextIndexed Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal index As Long, _
    ByVal substitutionText As String, _
    ByVal substitutionTextLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrText                                               */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message text for the top-level (i.e. most recent)  */
'/*   error identified by the error handle provided.                 */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   char * messageText - input/output                              */
'/*       Pointer to a buffer that will receive the message text     */
'/*       stored in the error identified by the handle.              */
'/*       The value returned is an ASCIIZ string.                    */
'/*                                                                  */
'/*   unsigned long messageTextLength - input                        */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrText Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal messageText As String, _
    ByVal messageTextLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long
  
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetErrTextIndexed                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message text for the message identified by the     */
'/*   index provided.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateErrHandle() API.                               */
'/*                                                                  */
'/*   unsigned long index - input                                    */
'/*       Index value indicating which message text to return if     */
'/*       multiple errors are associated with the error handle.      */
'/*       The valid index range is from 1 to the number of messages  */
'/*       contained in the error handle. The number of messages can  */
'/*       be obtained by calling the cwbSV_GetErrCount() API.        */
'/*                                                                  */
'/*   char * messageText - input/output                              */
'/*       Pointer to a buffer that will receive the message text     */
'/*       stored in the error identified by the index.               */
'/*       The value returned is an ASCIIZ string.                    */
'/*                                                                  */
'/*   unsigned long messageTextLength - input                        */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_NO_ERROR_MESSAGES - No messages are in the error handle. */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   An index value of 1 works with the lowest-level (i.e. oldest)  */
'/*   message in the error handle. An index value equal to the count */
'/*   returned by the cwbSV_GetErrCount() API works with the         */
'/*   top-level (i.e. most recent) message in the error handle.      */
'/*                                                                  */
'/*   Index values less than 1 act as if 1 was passed in. Index      */
'/*   values greater than the number of messages contained in the    */
'/*   error handle act as if the returned count value from the       */
'/*   cwbSV_GetErrCount() API was passed in.                         */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetErrTextIndexed Lib "cwbsv" _
  ( _
    ByVal errorHandle As Long, _
    ByVal index As Long, _
    ByVal messageText As String, _
    ByVal messageTextLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetFailMethod                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetFailModule                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetFailPathName                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetFailProductID                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetFailVersion                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetMaxRecordSize                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the size (in bytes) of the largest record in the       */
'/*   service file identified by the file handle provided.           */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   unsigned long * maxRecordSize - input/output                   */
'/*       Pointer to variable that receives the size of the          */
'/*       largest record in the file.                                */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetMaxRecordSize Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByRef maxRecordSize As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetMessageText                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the message text portion of the service record object  */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * messageText - input/output                              */
'/*       Pointer to a buffer that will receive the message text     */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*   unsigned long messageTextLength - input                        */
'/*       Length of the receive buffer passed in. If the buffer      */
'/*       is too small, the value will be truncated and              */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output data if the      */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parm               */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_MESSAGE_REC.     */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_MESSAGE_REC, a return code of  */
'/*   CWBSV_INVALID_RECORD_TYPE will be returned.                    */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetMessageText Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByVal messageText As String, _
    ByVal messageTextLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetOriginSystemID                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetOriginSystemIPAddr                                    */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetPreviousFix                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetProblemID                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetProblemStatus                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetProblemText                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetProblemType                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/* API:                                                             */
'/*   cwbSV_GetProduct                                               */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the product ID value for the service record object     */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * productID - input/output                                */
'/*       Pointer to a buffer that will receive the product ID       */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*   unsigned long productIDLength - input                          */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_PRODUCT_ID.        */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE  - Invalid handle.                          */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The service record handle needs to be filled in by a call to   */
'/*   a "read" function before calling this routine, otherwise a     */
'/*   NULL string will be returned.                                  */
'/*                                                                  */
'/*   This function is valid for all service record types.           */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetProduct Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByVal productID As String, _
    ByVal productIDLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetRecordCount                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the total numbers of records in the service file       */
'/*   identified by the file handle provided.                        */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   unsigned long * recordCount - input/output                     */
'/*       Pointer to variable that receives the total number of      */
'/*       records in the file.                                       */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetRecordCount Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByRef recordCount As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetServiceFileName                                       */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the fully-qualified path and file name of where        */
'/*   the service records are being logged to for a particular       */
'/*   file type.                                                     */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileType serviceFileType - input                  */
'/*      Value indicating which service file name you want returned. */
'/*        - CWBSV_HISTORY_LOG                                       */
'/*        - CWBSV_PROBLEM_LOG                                       */
'/*        - CWBSV_DETAIL_TRACE_FILE                                 */
'/*        - CWBSV_ENTRY_EXIT_TRACE_FILE                             */
'/*                                                                  */
'/*   char * fileName - input/output                                 */
'/*       Pointer to a buffer that will receive the service file     */
'/*       name associated with the one requested.                    */
'/*                                                                  */
'/*   unsigned long fileNameLength - input                           */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_FILE_PATH.         */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWBSV_INVALID_FILE_TYPE - Invalid file type passed-in.         */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The filename string returned could be used as input to the     */
'/*   cwbSV_OpenServiceFile() routine.                               */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetServiceFileName Lib "cwbsv" _
  ( _
    ByVal serviceFileType As Long, _
    ByVal fileName As String, _
    ByVal fileNameLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetServiceType                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the type of record (trace, message, entry/exit, etc..) */
'/*   for the service record identified by the handle provided.      */
'/*                                                                  */
'/*   Note: The service record needs to be filled in by a call to    */
'/*         a "read" function before calling this function.          */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   cwbSV_ServiceRecType * serviceType - output                    */
'/*       Pointer to a cwbSV_ServiceRecType where the serviceType    */
'/*       will be returned.                                          */
'/*           - CWBSV_MESSAGE_REC                                    */
'/*           - CWBSV_PROBLEM_REC                                    */
'/*           - CWBSV_DATA_TRACE_REC                                 */
'/*           - CWBSV_API_TRACE_REC                                  */
'/*           - CWBSV_SPI_TRACE_REC                                  */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Invalid record type detected.      */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The service record handle needs to be filled in by a call to   */
'/*   a "read" function before calling this routine, otherwise       */
'/*   CWBSV_INVALID_RECORD_TYPE will be returned.                    */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetServiceType Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef serviceType As Long, _
    ByRef errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetSeverity                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetSymptomString                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This is an obsolete API, there is no replacement API.          */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   CWB_NOT_SUPPORTED - Function no longer supported.              */
'/*                                                                  */
'/********************************************************************/

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTimeStamp                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the timestamp (in localized format) for the service    */
'/*   record identified by the handle provided.                      */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * timeStamp - input/output                                */
'/*       Pointer to a buffer that will receive the timestamp        */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*   unsigned long timeStampLength - input                          */
'/*       Length of the receive buffer passed in. It should          */
'/*       include space for the terminating null character. If the   */
'/*       buffer is too small, the value will be truncated and       */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*       NOTE: The recommended size is CWBSV_MAX_TIME_VALUE.        */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output string if the    */
'/*       receive buffer is too small.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The service record handle needs to be filled in by a call to   */
'/*   a "read" function before calling this routine, otherwise a     */
'/*   NULL string will be returned.                                  */
'/*                                                                  */
'/*   This function is valid for all service record types.           */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTimeStamp Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef timeStamp As Byte, _
    ByVal timeStampLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceAPIData                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the API trace data portion of the service record       */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * apiData - input/output                                  */
'/*       Pointer to a buffer that will receive the API trace data   */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*       Note: The data returned is binary, hence it is NOT         */
'/*             returned as an ASCIIZ string.                        */
'/*                                                                  */
'/*   unsigned long apiDataLength - input                            */
'/*       Length of the receive buffer passed in. If the buffer      */
'/*       is too small, the value will be truncated and              */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output data if the      */
'/*       receive buffer is too small. It will also be set to the    */
'/*       actual number of bytes of output data returned upon        */
'/*       successful completion.                                     */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output paraemter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_API_TRACE_REC.   */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_API_TRACE_REC, a return code   */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/*   Use the returnLength parameter to determine the actual number  */
'/*   of bytes returned in apiData when the return code is CWB_OK.   */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceAPIData Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef apiData As Byte, _
    ByVal apiDataLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceAPIID                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the API event ID of the service record object          */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * apiID - input/output                                    */
'/*       Pointer to one-byte field that receives the API event ID.  */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_API_TRACE_REC.   */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_API_TRACE_REC, a return code   */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceAPIID Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef apiID As Byte _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceAPIType                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the API event type of the service record object        */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   cwbSV_EventType * eventType - output                           */
'/*       Pointer to a cwbSV_EventType where the eventType           */
'/*       will be returned.                                          */
'/*           - CWBSV_ENTRY_POINT                                    */
'/*           - CWBSV_EXIT_POINT                                     */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_API_TRACE_REC.   */
'/*   CWBSV_INVALID_EVENT_TYPE - Invalid event type detected.        */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_API_TRACE_REC, a return code   */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceAPIType Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef eventType As Long, _
    ByVal errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceData                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the trace data portion of the service record object    */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * traceData - input/output                                */
'/*       Pointer to a buffer that will receive the trace data       */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*       Note: The data returned is binary, hence it is NOT         */
'/*             returned as an ASCIIZ string.                        */
'/*                                                                  */
'/*   unsigned long traceDataLength - input                          */
'/*       Length of the receive buffer passed in. If the buffer      */
'/*       is too small, the value will be truncated and              */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output data if the      */
'/*       receive buffer is too small. It will also be set to the    */
'/*       actual number of bytes of output data returned upon        */
'/*       successful completion.                                     */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_DATA_TRACE_REC.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_TRACE_DATA_REC, a return code  */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/*   Use the returnLength parameter to determine the actual number  */
'/*   of bytes returned in traceData when the return code is CWB_OK. */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceData Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef traceData As Byte, _
    ByVal traceDataLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceSPIData                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the SPI trace data portion of the service record       */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * spiData - input/output                                  */
'/*       Pointer to a buffer that will receive the SPI trace data   */
'/*       stored in the record identified by the handle.             */
'/*                                                                  */
'/*       Note: The data returned is binary, hence it is NOT         */
'/*             returned as an ASCIIZ string.                        */
'/*                                                                  */
'/*   unsigned long spiDataLength - input                            */
'/*       Length of the receive buffer passed in. If the buffer      */
'/*       is too small, the value will be truncated and              */
'/*       CWB_BUFFER_OVERFLOW and returnLength will be set.          */
'/*                                                                  */
'/*   unsigned long * returnLength - input/output                    */
'/*       Optional, may be NULL. A return address to store the       */
'/*       number of bytes needed to hold the output data if the      */
'/*       receive buffer is too small. It will also be set to the    */
'/*       actual number of bytes of output data returned upon        */
'/*       successful completion.                                     */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_SPI_TRACE_REC.   */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_SPI_TRACE_REC, a return code   */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/*   Use the returnLength parameter to determine the actual number  */
'/*   of bytes returned in spidata when the return code is CWB_OK.   */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceSPIData Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef spiData As Byte, _
    ByVal spiDataLength As Long, _
    ByRef returnLength As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceSPIID                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the SPI event ID of the service record object          */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   char * spiID - input/output                                    */
'/*       Pointer to one-byte field that receives the SPI event ID.  */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE  - Invalid handle.                          */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_SPI_TRACE_REC.   */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_SPI_TRACE_REC, a return code   */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceSPIID Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef spiID As Byte _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_GetTraceSPIType                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the SPI event type of the service record object        */
'/*   identified by the handle provided.                             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle() API.                        */
'/*                                                                  */
'/*   cwbSV_EventType * eventType - output                           */
'/*       Pointer to a cwbSV_EventType where the eventType           */
'/*       will be returned.                                          */
'/*           - CWBSV_ENTRY_POINT                                    */
'/*           - CWBSV_EXIT_POINT                                     */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWBSV_INVALID_RECORD_TYPE - Type is not CWBSV_SPI_TRACE_REC.   */
'/*   CWBSV_INVALID_EVENT_TYPE - Invalid event type detected.        */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   If the record type is not CWBSV_SPI_TRACE_REC, a return code   */
'/*   of CWBSV_INVALID_RECORD_TYPE will be returned.                 */
'/*   (note: cwbSV_GetServiceType() returns the current record type) */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_GetTraceSPIType Lib "cwbsv" _
  ( _
    ByVal serviceRecHandle As Long, _
    ByRef eventType As Long, _
    ByVal errorHandle As Long _
  ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_LogAPIEntry                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function will log an API entry point to the currently     */
'/*   active entry/exit trace file. The product and component ID's   */
'/*   set in the entry will be written along with the date and time  */
'/*   of the when the data was logged. The apiID along with any      */
'/*   optional data passed on the request will also be logged.       */
'/*                                                                  */
'/* Parameters:                                                      */
'/*                                                                  */
'/*   cwbSV_TraceAPIHandle traceAPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceAPIHandle() API.                          */
'/*                                                                  */
'/*   unsigned char apiID - input                                    */
'/*       A unique one-character code that will distinguish this     */
'/*       API trace point from others logged by your program.        */
'/*       Definition of these codes are left up to the caller of     */
'/*       this API. The recommended approach is to use the defined   */
'/*       range (0x00 - 0xFF) for each unique component in your      */
'/*       product (i.e. start at 0x00 for each component)            */
'/*                                                                  */
'/*   char * apiData - input                                         */
'/*       Points to a buffer that contains additional data           */
'/*       (e.g. input parameter values from your caller) that        */
'/*       you want to log along with this entry point.               */
'/*       Parameter is optional, it is ignored if the address is     */
'/*       NULL or the data length is zero. This buffer can           */
'/*       contain binary data because the length parameter is        */
'/*       used in determining the amount to trace.                   */
'/*                                                                  */
'/*   unsigned long apiDataLength - input                            */
'/*       Specifies the number of bytes in the API data buffer       */
'/*       to log for this trace entry.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should allows be used in conjunction with a          */
'/*   corresponding "cwbSV_LogAPIExit()". It is recommended that     */
'/*   these calls would be put at the beginning and end of an API    */
'/*   routine that you write. The other method would be to use these */
'/*   log functions around calls to external routines not written    */
'/*   by you.                                                        */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_LogAPIEntry Lib "cwbsv" _
  ( _
    ByVal traceAPIHandle As Long, _
    ByVal apiID As Byte, _
    ByVal apiData As String, _
    ByVal apiDataLength As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_LogAPIExit                                               */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function will log an API exit point to the currently      */
'/*   active entry/exit trace file. The product and component ID's   */
'/*   set in the entry will be written along with the date and time  */
'/*   of the when the data was logged. The API ID along with any     */
'/*   optional data passed on the request will also be logged.       */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceAPIHandle traceAPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceAPIHandle() API.                          */
'/*                                                                  */
'/*   unsigned char apiID - input                                    */
'/*       A unique one-character code that will distinguish this     */
'/*       API trace point from others logged by your program.        */
'/*       Definition of these codes are left up to the caller of     */
'/*       this API. The recommended approach is to use the defined   */
'/*       range (0x00 - 0xFF) for each unique component in your      */
'/*       product (i.e. start at 0x00 for each component)            */
'/*                                                                  */
'/*   char * apiData - input                                         */
'/*       Points to a buffer that contains additional data           */
'/*       (e.g. output parameter values passed back to your caller)  */
'/*       that you want to log along with this exit point.           */
'/*       Parameter is optional, it is ignored if the address is     */
'/*       NULL or the data length is zero. This buffer can           */
'/*       contain binary data because the length parameter is        */
'/*       used in determining the amount to trace.                   */
'/*                                                                  */
'/*   unsigned long apiDataLength - input                            */
'/*       Specifies the number of bytes in the API data buffer       */
'/*       to log for this trace entry.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should allows be used in conjunction with a          */
'/*   corresponding "cwbSV_LogAPIEntry()". It is recommended that    */
'/*   these calls would be put at the beginning and end of an API    */
'/*   routine that you write. The other method would be to use these */
'/*   log functions around calls to external routines not written    */
'/*   by you.                                                        */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_LogAPIExit Lib "cwbsv" _
  ( _
    ByVal traceAPIHandle As Long, _
    ByVal apiID As Byte, _
    ByVal apiData As String, _
    ByVal apiDataLength As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_LogMessageText                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function will log the supplied message text to the        */
'/*   currently active history log. The product and component ID's   */
'/*   set in the entry will be written along with the date and time  */
'/*   of the when the text was logged.                               */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_MessageTextHandle messageTextHandle - input              */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateMessageTextHandle() API.                       */
'/*                                                                  */
'/*   char *  messageText - input                                    */
'/*       Points to a buffer that contains the message text you      */
'/*       want to log.                                               */
'/*                                                                  */
'/*   unsigned long messageTextLength - input                        */
'/*       Specifies the number of bytes in the message text buffer   */
'/*       to log for this message entry.                             */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle passed in on request.      */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_LogMessageText Lib "cwbsv" _
  ( _
    ByVal messageTextHandle As Long, _
    ByVal messageText As String, _
    ByVal messageTextLength As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_LogSPIEntry                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function will log an SPI entry point to the currently     */
'/*   active entry/exit trace file. The product and component ID's   */
'/*   set in the entry will be written along with the date and time  */
'/*   of the when the data was logged. The spiID along with any      */
'/*   optional data passed on the request will also be logged.       */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceSPIHandle traceSPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceSPIHandle() API.                          */
'/*                                                                  */
'/*   unsigned char spiID - input                                    */
'/*       A unique one-character code that will distinguish this     */
'/*       SPI trace point from others logged by your program.        */
'/*       Definition of these codes are left up to the caller of     */
'/*       this API. The recommended approach is to use the defined   */
'/*       range (0x00 - 0xFF) for each unique component in your      */
'/*       product (i.e. start at 0x00 for each component)            */
'/*                                                                  */
'/*   char * spiData - input                                         */
'/*       Points to a buffer that contains additional data           */
'/*       (e.g. input parameter values from your caller) that        */
'/*       you want to log along with this entry point.               */
'/*       Parameter is optional, it is ignored if the address is     */
'/*       NULL or the data length is zero. This buffer can           */
'/*       contain binary data because the length parameter is        */
'/*       used in determining the amount to trace.                   */
'/*                                                                  */
'/*   unsigned long  spiDataLength - input                           */
'/*       Specifies the number of bytes in the SPI data buffer       */
'/*       to log for this trace entry.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should allows be used in conjunction with a          */
'/*   corresponding "cwbSV_LogSPIExit()". It is recommended that     */
'/*   these calls would be put at the beginning and end of an API    */
'/*   routine that you write. The other method would be to use these */
'/*   log functions around calls to external routines not written    */
'/*   by you.                                                        */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_LogSPIEntry Lib "cwbsv" _
  ( _
    ByVal traceSPIHandle As Long, _
    ByVal spiID As Byte, _
    ByVal spiData As String, _
    ByVal spiDataLength As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_LogSPIExit                                               */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function will log an SPI exit point to the currently      */
'/*   active entry/exit trace file. The product and component ID's   */
'/*   set in the entry will be written along with the date and time  */
'/*   of the when the data was logged. The spiID along with any      */
'/*   optional data passed on the request will also be logged.       */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceSPIHandle traceSPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceSPIHandle() API.                          */
'/*                                                                  */
'/*   unsigned char spiID - input                                    */
'/*       A unique one-character code that will distinguish this     */
'/*       SPI trace point from others logged by your program.        */
'/*       Definition of these codes are left up to the caller of     */
'/*       this API. The recommended approach is to use the defined   */
'/*       range (0x00 - 0xFF) for each unique component in your      */
'/*       product (i.e. start at 0x00 for each component)            */
'/*                                                                  */
'/*   char * spiData - input                                         */
'/*       Points to a buffer that contains additional data           */
'/*       (e.g. output parameter values passed back to your caller)  */
'/*       that you want to log along with this exit point.           */
'/*       Parameter is optional, it is ignored if the address is     */
'/*       NULL or the data length is zero. This buffer can           */
'/*       contain binary data because the length parameter is        */
'/*       used in determining the amount to trace.                   */
'/*                                                                  */
'/*   unsigned long spiDataLength - input                            */
'/*       Specifies the number of bytes in the SPI data buffer       */
'/*       to log for this trace entry.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This call should allows be used in conjunction with a          */
'/*   corresponding "cwbSV_LogSPIEntry()". It is recommended that    */
'/*   these calls would be put at the beginning and end of an API    */
'/*   routine that you write. The other method would be to use these */
'/*   log functions around calls to external routines not written    */
'/*   by you.                                                        */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_LogSPIExit Lib "cwbsv" _
  ( _
    ByVal traceSPIHandle As Long, _
    ByVal spiID As Byte, _
    ByVal spiData As String, _
    ByVal spiDataLength As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_LogTraceData                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function will log the supplied trace data to the          */
'/*   currently active trace file. The product and component ID's    */
'/*   set in the entry will be written along with the date and time  */
'/*   of the when the data was logged.                               */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceDataHandle traceDataHandle - input                  */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceDataHandle() API.                         */
'/*                                                                  */
'/*   char * traceData - input                                       */
'/*       Points to a buffer that contains the trace data you want   */
'/*       to log. The buffer can contain binary data because the     */
'/*       length parameter is used in determining the amount to      */
'/*       trace.                                                     */
'/*                                                                  */
'/*   unsigned long traceDataLength - input                          */
'/*       Specifies the number of bytes in the trace data buffer     */
'/*       to log for this trace entry.                               */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_LogTraceData Lib "cwbsv" _
  ( _
    ByVal traceDataHandle As Long, _
    ByVal traceData As Byte, _
    ByVal traceDataLength As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_OpenServiceFile                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Opens the specified service file for READ access (history log, */
'/*   trace file, etc..) and returns a handle to it.                 */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   char * serviceFileName - input                                 */
'/*       Points to a buffer that contains the fully-qualified       */
'/*       name (e.g. c:\path\filename.ext) of the service file       */
'/*       to open.                                                   */
'/*                                                                  */
'/*   cwbSV_ServiceFileHandle * serviceFileHandle - input/output     */
'/*       Pointer to a cwbSV_ServiceFileHandle where the handle      */
'/*       will be returned. This handle should be used in            */
'/*       subsequent calls to the service file functions.            */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_POINTER - NULL passed as handle address.           */
'/*   CWB_FILE_IO_ERROR - File could not be opened.                  */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory to create handle.  */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_OpenServiceFile Lib "cwbsv" _
  ( _
    ByVal serviceFileName As String, _
    ByRef serviceFileHandle As Long, _
    ByVal errorHandle As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_ReadNewestRecord                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Reads the newest record in the service file into the record    */
'/*   handle provided. Subsequent calls can be made to retrieve      */
'/*   the information stored in this record (e.g. cwbSV_GetProduct(),*/
'/*   cwbSV_GetDateStamp(), etc...).                                 */
'/*                                                                  */
'/*   Note: This record is the one with the newest time and          */
'/*         date stamp in the file.                                  */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle function.                     */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_END_OF_FILE - End of file has been reached.                */
'/*   CWB_FILE_IO_ERROR - Record could not be read.                  */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This read would be used as a "priming-type" read before        */
'/*   issuing a series of cwbsv_ReadPrevRecord() calls until the     */
'/*   the end-of-file indicator is returned.                         */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_ReadNewestRecord Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByVal serviceRecHandle As Long, _
    ByVal errorHandle As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_ReadNextRecord                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Reads the next record in the service file into the record      */
'/*   handle provided. Subsequent calls can be made to retrieve      */
'/*   the information stored in this record (e.g. cwbSV_GetProduct(),*/
'/*   cwbSV_GetDateStamp(), etc...).                                 */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle function.                     */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_END_OF_FILE - End of file has been reached.                */
'/*   CWB_FILE_IO_ERROR - Record could not be read.                  */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This read would normally be used once the priming read,        */
'/*   "ReadOldestRecord()" is performed.                             */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_ReadNextRecord Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByVal serviceRecHandle As Long, _
    ByVal errorHandle As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_ReadOldestRecord                                         */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Reads the oldest record in the service file into the record    */
'/*   handle provided. Subsequent calls can be made to retrieve      */
'/*   the information stored in this record (e.g. cwbSV_GetProduct(),*/
'/*   cwbSV_GetDateStamp(), etc...).                                 */
'/*                                                                  */
'/*   Note: This record is the one with the oldest time and          */
'/*         date stamp in the file.                                  */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   cwbSV_ServiceRecHandle serviceRecHandle - input                */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle function.                     */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_END_OF_FILE - End of file has been reached.                */
'/*   CWB_FILE_IO_ERROR - Record could not be read.                  */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This read would be used as a "priming-type" read before        */
'/*   issuing a series of cwbsv_ReadNextRecord() calls until the     */
'/*   the end-of-file indicator is returned.                         */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_ReadOldestRecord Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByVal serviceRecHandle As Long, _
    ByVal errorHandle As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_ReadPrevRecord                                           */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Reads the previous record in the service file into the record  */
'/*   handle provided. Subsequent calls can be made to retrieve      */
'/*   the information stored in this record (e.g. cwbSV_GetProduct(),*/
'/*   cwbSV_GetDateStamp(), etc...).                                 */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_ServiceFileHandle serviceFileHandle - input              */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_OpenServiceFile() API.                               */
'/*                                                                  */
'/*   cwbSV_ServiceRecHandle serviceRecHandle -input                 */
'/*       Handle that was returned by a previous call to the         */
'/*       cwbSV_CreateServiceRecHandle function.                     */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - output                           */
'/*     Any returned messages will be written to this object.  It    */
'/*     is created with the cwbSV_CreateErrHandle API.  The          */
'/*     messages may be retrieved through the cwbSV_GetErrText API.  */
'/*     If the parameter is set to zero, no messages will be         */
'/*     retrieved.                                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_END_OF_FILE - End of file has been reached.                */
'/*   CWB_FILE_IO_ERROR - Record could not be read.                  */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This read would normally be used once the priming read,        */
'/*   "ReadNewestRecord()" is performed.                             */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_ReadPrevRecord Lib "cwbsv" _
  ( _
    ByVal serviceFileHandle As Long, _
    ByVal serviceRecHandle As Long, _
    ByVal errorHandle As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetMessageClass                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of the message class (severity)   */
'/*   to associate with the message being written to the history     */
'/*   log.                                                           */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_MessageTextHandle messageTextHandle - input              */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateMessageTextHandle() API.                       */
'/*                                                                  */
'/*   cwbSV_MessageClass messageClass - input                        */
'/*       One of the following:                                      */
'/*         - CWBSV_CLASS_INFORMATIONAL                              */
'/*         - CWBSV_CLASS_WARNING                                    */
'/*         - CWBSV_CLASS_ERROR                                      */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle passed in on request.      */
'/*   CWBSV_INVALID_MSG_CLASS - Invalid message class passed in.     */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log function, "cwbSV_LogMessageText()".                        */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetMessageClass Lib "cwbsv" _
  ( _
    ByVal messageTextHandle As Long, _
    ByVal messageClass As Long _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetMessageComponent                                      */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique component identifier  */
'/*   in the message handle provided. Along with setting the         */
'/*   product ID (see cwbSV_SetMessageProduct), this call should     */
'/*   be used to distinguish your message entries from other         */
'/*   product's entries in the history log.                          */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_MessageTextHandle messageTextHandle - input              */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateMessageTextHandle() API.                       */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this message entry.     */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle passed in on request.      */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log function, "cwbSV_LogMessageText()".                        */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetMessageComponent Lib "cwbsv" _
  ( _
    ByVal messageTextHandle As Long, _
    ByVal componentID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetMessageProduct                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique product identifier in */
'/*   the message handle provided. Along with setting the component  */
'/*   ID (see cwbSV_SetMessageComponent), this call should be used   */
'/*   to distinguish your message entries from other product's       */
'/*   entries in the history log.                                    */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_MessageTextHandle messageTextHandle - input              */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateMessageTextHandle() API.                       */
'/*                                                                  */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this message entry.       */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle passed in on request.      */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log function, "cwbSV_LogMessageText()".                        */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetMessageProduct Lib "cwbsv" _
  ( _
    ByVal messageTextHandle As Long, _
    ByVal productID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetAPIComponent                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique component identifier  */
'/*   in trace entry provided. Along with setting the product        */
'/*   ID (see cwbSV_SetAPIProduct), this call should be used to      */
'/*   distinguish your trace entries from other product's entries in */
'/*   the trace file.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceAPIHandle traceAPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceAPIHandle() API.                          */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this trace entry.       */
'/*                                                                  */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log functions, "cwbSV_LogAPIEntry()" or "cwbSV_LogAPIExit().   */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetAPIComponent Lib "cwbsv" _
  ( _
    ByVal traceAPIHandle As Long, _
    ByVal componentID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetAPIProduct                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique product identifier in */
'/*   the trace handle provided. Along with setting the component    */
'/*   ID (see cwbSV_SetAPIComponent), this call should be used to    */
'/*   distinguish your trace entries from other product's entries in */
'/*   the trace file.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceAPIHandle traceAPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceAPIHandle() API.                          */
'/*                                                                  */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this trace entry.         */
'/*                                                                  */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log functions, "cwbSV_LogAPIEntry()" or "cwbSV_LogAPIExit().   */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetAPIProduct Lib "cwbsv" _
  ( _
    ByVal traceAPIHandle As Long, _
    ByVal productID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetSPIComponent                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique component identifier  */
'/*   in trace entry provided. Along with setting the product        */
'/*   ID (see cwbSV_SetSPIProduct), this call should be used to      */
'/*   distinguish your trace entries from other product's entries in */
'/*   the trace file.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceSPIHandle traceSPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceSPIHandle() API.                          */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this trace entry.       */
'/*                                                                  */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log functions, "cwbSV_LogAPIEntry()" or "cwbSV_LogAPIExit().   */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetSPIComponent Lib "cwbsv" _
  ( _
    ByVal traceSPIHandle As Long, _
    ByVal componentID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetSPIProduct                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique product identifier in */
'/*   the trace handle provided. Along with setting the component    */
'/*   ID (see cwbSV_SetSPIComponent), this call should be used to    */
'/*   distinguish your trace entries from other product's entries in */
'/*   the trace file.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceSPIHandle traceSPIHandle - input                    */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceSPIHandle() API.                          */
'/*                                                                  */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this trace entry.         */
'/*                                                                  */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log functions, "cwbSV_LogAPIEntry()" or "cwbSV_LogAPIExit().   */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetSPIProduct Lib "cwbsv" _
  ( _
    ByVal traceSPIHandle As Long, _
    ByVal productID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetTraceComponent                                        */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique component identifier  */
'/*   in service entry provided. Along with setting the product      */
'/*   ID (see cwbSV_SetTraceProduct), this call should be used to    */
'/*   distinguish your trace entries from other product's entries in */
'/*   the trace file.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceDataHandle traceDataHandle - input                  */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceDataHandle() API.                         */
'/*                                                                  */
'/*   char * componentID - input                                     */
'/*       Points to a null-terminated string that contains a         */
'/*       component identifier to be used on this trace entry.       */
'/*                                                                  */
'/*       NOTE: A maximum of CWBSV_MAX_COMP_ID characters will       */
'/*             be logged for the component ID. Larger strings       */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log function, "cwbSV_LogTraceData()".                          */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetTraceComponent Lib "cwbsv" _
  ( _
    ByVal traceDataHandle As Long, _
    ByVal componentID As String _
 ) _
  As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbSV_SetTraceProduct                                          */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   This function allows setting of a unique product identifier in */
'/*   the trace handle provided. Along with setting the component    */
'/*   ID (see cwbSV_SetTraceComponent), this call should be used to  */
'/*   distinguish your trace entries from other product's entries in */
'/*   the trace file.                                                */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   cwbSV_TraceDataHandle traceDataHandle - input                  */
'/*       Handle that was returned by a previous call to             */
'/*       cwbSV_CreateTraceDataHandle() API.                         */
'/*                                                                  */
'/*   char * productID - input                                       */
'/*       Points to a null-terminated string that contains a         */
'/*       product identifier to be used on this trace entry.         */
'/*                                                                  */
'/*       NOTE: A maximum of CWBSV_MAX_PRODUCT_ID characters will    */
'/*             be logged for the product ID. Larger strings         */
'/*             will be truncated.                                   */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   This value should be set before calling the corresponding      */
'/*   log function, "cwbSV_LogTraceData()".                          */
'/*   The suggested hierarchy is that you would define a product ID  */
'/*   with one or many components defined under it.                  */
'/*                                                                  */
'/********************************************************************/
Public Declare Function cwbSV_SetTraceProduct Lib "cwbsv" _
  ( _
    ByVal traceDataHandle As Long, _
    ByVal productID As String _
 ) _
  As Long
